{% if info %}
<div class="alert alert-info">
    {{ info }}
</div>
{% endif %}

{% if error %}
<div class="alert alert-danger">
    {{ error }}
</div>
{% endif %}

{% if warning %}
<div class="alert alert-warning">
    {{ warning }}
</div>
{% endif %}

{% if success %}
<div class="alert alert-success">
    {{ success }}
</div>
{% endif %}
