# Generated by Django 2.2 on 2022-06-10 05:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django', '0005_grid_filter'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='column',
            name='criteria',
        ),
        migrations.RemoveField(
            model_name='column',
            name='hidden',
        ),
        migrations.RemoveField(
            model_name='column',
            name='value',
        ),
        migrations.AddField(
            model_name='column',
            name='sort',
            field=models.IntegerField(default=0),
        ),
    ]
