<div class="form-group">
    <div class="col-sm-4"><label>{{field.label}}</label></div>
    <div class="col-sm-8">
        <input name="{{field.key}}"
               class="form-control"
               type="text"
               value="{{field.value_as_str}}"
               {% if field.disabled %}disabled{% endif %}/>
        {% for error in field.errors %}
        <div class="red">{{ error }}</div>
        {% endfor %}
    </div>
</div>