# Generated by Django 2.2 on 2022-02-11 07:30

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Grid',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, default='', max_length=255, null=True)),
                ('table', models.CharField(blank=True, default='', max_length=255, null=True)),
                ('comment', models.CharField(blank=True, default='', max_length=255, null=True)),
                ('filter_by', models.CharField(blank=True, default='', max_length=512, null=True)),
                ('group_by', models.BooleanField(default=False)),
                ('distinct', models.BooleanField(default=False)),
                ('show_on_home', models.BooleanField(default=False)),
            ],
        ),
        migrations.AlterField(
            model_name='log',
            name='user',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='actor', to=settings.AUTH_USER_MODEL),
        ),
        migrations.CreateModel(
            name='Column',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('label', models.CharField(blank=True, default='', max_length=255, null=True)),
                ('value', models.CharField(blank=True, default='', max_length=255, null=True)),
                ('criteria', models.IntegerField(default=1)),
                ('width', models.IntegerField(blank=True, default=80, null=True)),
                ('order', models.IntegerField(default=0)),
                ('hidden', models.BooleanField(default=False)),
                ('grid', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='django.Grid')),
            ],
        ),
    ]
